[Bf-blender-cvs] [23254ce4ee6] master: Cleanup: Rename: Static Override -> Library Override.

Bastien Montagne noreply at git.blender.org
Fri Jun 14 23:35:47 CEST 2019


Commit: 23254ce4ee6b21b202549b421cf1d98f6a03b33d
Author: Bastien Montagne
Date:   Fri Jun 14 23:16:04 2019 +0200
Branches: master
https://developer.blender.org/rB23254ce4ee6b21b202549b421cf1d98f6a03b33d

Cleanup: Rename: Static Override -> Library Override.

Better to make internal code naming match official/UI naming to some
extent, this will reduce confusion in the future.

This is 'breaking' scripts and files that would use that feature, but
since it is not yet officially supported nor exposed in 2.80, as far
as that release is concerned, it is effectively
a 'no functional changes' commit.

===================================================================

M	release/scripts/modules/rna_prop_ui.py
M	release/scripts/startup/bl_operators/wm.py
M	source/blender/blenkernel/BKE_library_override.h
M	source/blender/blenkernel/BKE_library_query.h
M	source/blender/blenkernel/BKE_library_remap.h
M	source/blender/blenkernel/intern/constraint.c
M	source/blender/blenkernel/intern/gpencil_modifier.c
M	source/blender/blenkernel/intern/library.c
M	source/blender/blenkernel/intern/library_override.c
M	source/blender/blenkernel/intern/library_query.c
M	source/blender/blenkernel/intern/library_remap.c
M	source/blender/blenkernel/intern/modifier.c
M	source/blender/blenkernel/intern/shader_fx.c
M	source/blender/blenkernel/intern/undo_system.c
M	source/blender/blenloader/intern/readfile.c
M	source/blender/blenloader/intern/writefile.c
M	source/blender/depsgraph/intern/eval/deg_eval_flush.cc
M	source/blender/editors/interface/interface.c
M	source/blender/editors/interface/interface_context_menu.c
M	source/blender/editors/interface/interface_ops.c
M	source/blender/editors/interface/interface_templates.c
M	source/blender/editors/object/object_constraint.c
M	source/blender/editors/object/object_gpencil_modifier.c
M	source/blender/editors/object/object_intern.h
M	source/blender/editors/object/object_modifier.c
M	source/blender/editors/object/object_ops.c
M	source/blender/editors/object/object_relations.c
M	source/blender/editors/object/object_shader_fx.c
M	source/blender/editors/space_outliner/outliner_draw.c
M	source/blender/editors/space_outliner/outliner_tools.c
M	source/blender/makesdna/DNA_ID.h
M	source/blender/makesdna/DNA_constraint_types.h
M	source/blender/makesdna/DNA_gpencil_modifier_types.h
M	source/blender/makesdna/DNA_modifier_types.h
M	source/blender/makesdna/DNA_shader_fx_types.h
M	source/blender/makesrna/RNA_access.h
M	source/blender/makesrna/RNA_types.h
M	source/blender/makesrna/intern/rna_ID.c
M	source/blender/makesrna/intern/rna_access.c
M	source/blender/makesrna/intern/rna_animation.c
M	source/blender/makesrna/intern/rna_collection.c
M	source/blender/makesrna/intern/rna_constraint.c
M	source/blender/makesrna/intern/rna_fcurve.c
M	source/blender/makesrna/intern/rna_gpencil_modifier.c
M	source/blender/makesrna/intern/rna_image.c
M	source/blender/makesrna/intern/rna_internal.h
M	source/blender/makesrna/intern/rna_internal_types.h
M	source/blender/makesrna/intern/rna_layer.c
M	source/blender/makesrna/intern/rna_modifier.c
M	source/blender/makesrna/intern/rna_object.c
M	source/blender/makesrna/intern/rna_pose.c
M	source/blender/makesrna/intern/rna_rna.c
M	source/blender/makesrna/intern/rna_scene.c
M	source/blender/makesrna/intern/rna_shader_fx.c
M	source/blender/python/intern/bpy_app.c
M	source/blender/python/intern/bpy_rna.c
M	source/creator/creator_args.c

===================================================================

diff --git a/release/scripts/modules/rna_prop_ui.py b/release/scripts/modules/rna_prop_ui.py
index 9660a2d29be..50becba0e3f 100644
--- a/release/scripts/modules/rna_prop_ui.py
+++ b/release/scripts/modules/rna_prop_ui.py
@@ -168,7 +168,7 @@ def rna_idprop_ui_create(
 
     prop_path = rna_idprop_quote_path(prop)
 
-    item.property_overridable_static_set(prop_path, overridable)
+    item.property_overridable_library_set(prop_path, overridable)
 
     return rna_ui
 
diff --git a/release/scripts/startup/bl_operators/wm.py b/release/scripts/startup/bl_operators/wm.py
index 6b3939cc056..c7e2b78d872 100644
--- a/release/scripts/startup/bl_operators/wm.py
+++ b/release/scripts/startup/bl_operators/wm.py
@@ -1079,8 +1079,8 @@ rna_use_soft_limits = BoolProperty(
     name="Use Soft Limits",
 )
 
-rna_is_overridable_static = BoolProperty(
-    name="Is Statically Overridable",
+rna_is_overridable_library = BoolProperty(
+    name="Is Library Overridable",
     default=False,
 )
 
@@ -1098,7 +1098,7 @@ class WM_OT_properties_edit(Operator):
     min: rna_min
     max: rna_max
     use_soft_limits: rna_use_soft_limits
-    is_overridable_static: rna_is_overridable_static
+    is_overridable_library: rna_is_overridable_library
     soft_min: rna_min
     soft_max: rna_max
     description: StringProperty(
@@ -1166,7 +1166,7 @@ class WM_OT_properties_edit(Operator):
         # print(exec_str)
         exec(exec_str)
 
-        exec_str = "item.property_overridable_static_set('[\"%s\"]', %s)" % (prop, self.is_overridable_static)
+        exec_str = "item.property_overridable_library_set('[\"%s\"]', %s)" % (prop, self.is_overridable_library)
         exec(exec_str)
 
         rna_idprop_ui_prop_update(item, prop)
@@ -1243,8 +1243,8 @@ class WM_OT_properties_edit(Operator):
         item = eval("context.%s" % data_path)
 
         # retrieve overridable static
-        exec_str = "item.is_property_overridable_static('[\"%s\"]')" % (self.property)
-        self.is_overridable_static = bool(eval(exec_str))
+        exec_str = "item.is_property_overridable_library('[\"%s\"]')" % (self.property)
+        self.is_overridable_library = bool(eval(exec_str))
 
         # default default value
         prop_type = type(self.get_value_eval())
@@ -1320,8 +1320,8 @@ class WM_OT_properties_edit(Operator):
 
         row = layout.row()
         row.prop(self, "use_soft_limits")
-        if bpy.app.use_static_override:
-            row.prop(self, "is_overridable_static")
+        if bpy.app.use_library_override:
+            row.prop(self, "is_overridable_library")
 
         row = layout.row(align=True)
         row.enabled = self.use_soft_limits
diff --git a/source/blender/blenkernel/BKE_library_override.h b/source/blender/blenkernel/BKE_library_override.h
index bdecff87cf1..5440b0ebe63 100644
--- a/source/blender/blenkernel/BKE_library_override.h
+++ b/source/blender/blenkernel/BKE_library_override.h
@@ -25,39 +25,39 @@
  */
 
 struct ID;
-struct IDOverrideStatic;
-struct IDOverrideStaticProperty;
-struct IDOverrideStaticPropertyOperation;
+struct IDOverrideLibrary;
+struct IDOverrideLibraryProperty;
+struct IDOverrideLibraryPropertyOperation;
 struct Main;
 
-void BKE_override_static_enable(const bool do_enable);
-bool BKE_override_static_is_enabled(void);
+void BKE_override_library_enable(const bool do_enable);
+bool BKE_override_library_is_enabled(void);
 
-struct IDOverrideStatic *BKE_override_static_init(struct ID *local_id, struct ID *reference_id);
-void BKE_override_static_copy(struct ID *dst_id, const struct ID *src_id);
-void BKE_override_static_clear(struct IDOverrideStatic *override);
-void BKE_override_static_free(struct IDOverrideStatic **override);
+struct IDOverrideLibrary *BKE_override_library_init(struct ID *local_id, struct ID *reference_id);
+void BKE_override_library_copy(struct ID *dst_id, const struct ID *src_id);
+void BKE_override_library_clear(struct IDOverrideLibrary *override);
+void BKE_override_library_free(struct IDOverrideLibrary **override);
 
-struct ID *BKE_override_static_create_from_id(struct Main *bmain, struct ID *reference_id);
-bool BKE_override_static_create_from_tag(struct Main *bmain);
+struct ID *BKE_override_library_create_from_id(struct Main *bmain, struct ID *reference_id);
+bool BKE_override_library_create_from_tag(struct Main *bmain);
 
-struct IDOverrideStaticProperty *BKE_override_static_property_find(
-    struct IDOverrideStatic *override, const char *rna_path);
-struct IDOverrideStaticProperty *BKE_override_static_property_get(
-    struct IDOverrideStatic *override, const char *rna_path, bool *r_created);
-void BKE_override_static_property_delete(struct IDOverrideStatic *override,
-                                         struct IDOverrideStaticProperty *override_property);
+struct IDOverrideLibraryProperty *BKE_override_library_property_find(
+    struct IDOverrideLibrary *override, const char *rna_path);
+struct IDOverrideLibraryProperty *BKE_override_library_property_get(
+    struct IDOverrideLibrary *override, const char *rna_path, bool *r_created);
+void BKE_override_library_property_delete(struct IDOverrideLibrary *override,
+                                          struct IDOverrideLibraryProperty *override_property);
 
-struct IDOverrideStaticPropertyOperation *BKE_override_static_property_operation_find(
-    struct IDOverrideStaticProperty *override_property,
+struct IDOverrideLibraryPropertyOperation *BKE_override_library_property_operation_find(
+    struct IDOverrideLibraryProperty *override_property,
     const char *subitem_refname,
     const char *subitem_locname,
     const int subitem_refindex,
     const int subitem_locindex,
     const bool strict,
     bool *r_strict);
-struct IDOverrideStaticPropertyOperation *BKE_override_static_property_operation_get(
-    struct IDOverrideStaticProperty *override_property,
+struct IDOverrideLibraryPropertyOperation *BKE_override_library_property_operation_get(
+    struct IDOverrideLibraryProperty *override_property,
     const short operation,
     const char *subitem_refname,
     const char *subitem_locname,
@@ -66,32 +66,32 @@ struct IDOverrideStaticPropertyOperation *BKE_override_static_property_operation
     const bool strict,
     bool *r_strict,
     bool *r_created);
-void BKE_override_static_property_operation_delete(
-    struct IDOverrideStaticProperty *override_property,
-    struct IDOverrideStaticPropertyOperation *override_property_operation);
+void BKE_override_library_property_operation_delete(
+    struct IDOverrideLibraryProperty *override_property,
+    struct IDOverrideLibraryPropertyOperation *override_property_operation);
 
-bool BKE_override_static_status_check_local(struct Main *bmain, struct ID *local);
-bool BKE_override_static_status_check_reference(struct Main *bmain, struct ID *local);
+bool BKE_override_library_status_check_local(struct Main *bmain, struct ID *local);
+bool BKE_override_library_status_check_reference(struct Main *bmain, struct ID *local);
 
-bool BKE_override_static_operations_create(struct Main *bmain,
-                                           struct ID *local,
-                                           const bool force_auto);
-void BKE_main_override_static_operations_create(struct Main *bmain, const bool force_auto);
+bool BKE_override_library_operations_create(struct Main *bmain,
+                                            struct ID *local,
+                                            const bool force_auto);
+void BKE_main_override_library_operations_create(struct Main *bmain, const bool force_auto);
 
-void BKE_override_static_update(struct Main *bmain, struct ID *local);
-void BKE_main_override_static_update(struct Main *bmain);
+void BKE_override_library_update(struct Main *bmain, struct ID *local);
+void BKE_main_override_library_update(struct Main *bmain);
 
 /* Storage (.blend file writing) part. */
 
 /* For now, we just use a temp main list. */
-typedef struct Main OverrideStaticStorage;
+typedef struct Main OverrideLibraryStorage;
 
-OverrideStaticStorage *BKE_override_static_operations_store_initialize(void);
-struct ID *BKE_override_static_operations_store_start(struct Main *bmain,
-                                                      OverrideStaticStorage *override_storage,
-                                                      struct ID *local);
-void BKE_override_static_operations_store_end(OverrideStaticStorage *override_storage,
-                                              struct ID *local);
-void BKE_override_static_operations_store_finalize(OverrideStaticStorage *override_storage);
+OverrideLibraryStorage *BKE_override_library_operations_store_initialize(void);
+struct ID *BKE_override_library_operations_store_start(struct Main *bmain,
+                                                       OverrideLibraryStorage *override_storage,
+                                                       struct ID *local);
+void BKE_override_library_operations_store_end(OverrideLibraryStorage *override_storage,
+                                               struct ID *local);
+void BKE_override_library_operations_store_finalize(OverrideLibraryStorage *override_storage);
 
 #endif /* __BKE_LIBRARY_OVERRIDE_H__ */
diff --git a/source/blender/blenkernel/BKE_library_remap.h b/source/blender/blenkernel/BKE_library_remap.h
index 41ac8c8c8e6..d51bc5c2bce 100644
--- a/source/blender/blenkernel/BKE_library_remap.h
+++ b/source/blender/blenkernel/BKE_library_remap.h
@@ -61,8 +61,8 @@ enum {
    * is also performed. Usual nig

@@ Diff output truncated at 10240 characters. @@



More information about the Bf-blender-cvs mailing list
diff --git a/source/blender/blenkernel/BKE_library_query.h b/source/blender/blenkernel/BKE_library_query.h
index 94e7830aabe..4f74b2b5a6b 100644
--- a/source/blender/blenkernel/BKE_library_query.h
+++ b/source/blender/blenkernel/BKE_library_query.h
@@ -51,8 +51,8 @@ enum {
    * How to handle that kind of cases totally depends on what caller code is doing... */
   IDWALK_CB_LOOPBACK = (1 << 4),
 
-  /** That ID is used as static override's reference by its owner. */
-  IDWALK_CB_STATIC_OVERRIDE_REFERENCE = (1 << 5),
+  /** That ID is used as library override's reference by its owner. */
+  IDWALK_CB_OVERRIDE_LIBRARY_REFERENCE = (1 << 5),
 
   /**
    * Adjusts #ID.us reference-count.